@@ -8,25 +8,38 @@
 # http://www.opensource.org/licenses/mit-license
 # Copyright (c) 2011 globo.com timehome@corp.globo.com
 
-from os.path import join, dirname, abspath
+from io import BytesIO
+from os.path import abspath, dirname, join
 
 import cv2
 import numpy as np
 
 
-class BaseDetector(object):
-    def get_np_img(self, image):
-        return np.array(image)
+class BaseDetector:
+    def __get_format(self, image):
+        fmt = image.format
+        if fmt == "GIF":
+            return "PNG"
+        return fmt
 
-    def detect(self, context):
+    def get_np_img(self, image):
+        img_buffer = BytesIO()
+        image.save(img_buffer, self.__get_format(image))
+        results = img_buffer.getvalue()
+        img_buffer.close()
+        nparr = np.fromstring(results, np.uint8)
+        return cv2.imdecode(nparr, cv2.IMREAD_UNCHANGED)  # pylint: disable=no-member
+
+    def detect(self, image):
         raise NotImplementedError()
 
 
 class CascadeLoaderDetector(BaseDetector):
-
     def load_cascade_file(self, module_path, cascade_file_path):
         cascade_file = join(abspath(dirname(module_path)), cascade_file_path)
-        self.__class__.cascade = cv2.CascadeClassifier(cascade_file)
+        self.__class__.cascade = cv2.CascadeClassifier(  # pylint: disable=no-member
+            cascade_file
+        )
 
     def get_min_size_for(self, size):
         ratio = int(min(size[0], size[1]) / 15)
@@ -37,22 +50,13 @@ class CascadeLoaderDetector(BaseDetector):
         img = self.get_np_img(image)
 
         faces = self.__class__.cascade.detectMultiScale(
-            img,
-            1.2,
-            4,
-            minSize=self.get_min_size_for(image.size)
+            img, 1.2, 4, minSize=self.get_min_size_for(image.size)
         )
         faces_scaled = []
 
-        for (x, y, w, h) in faces:
+        for (left, top, width, height) in faces:
             faces_scaled.append(
-                (
-                    (
-                        x.item(),
-                        y.item(),
-                        w.item(),
-                        h.item()
-                    ), 0)
+                ((left.item(), top.item(), width.item(), height.item()), 0)
             )
 
         return faces_scaled
@@ -61,7 +65,10 @@ class CascadeLoaderDetector(BaseDetector):
         features = self.get_features(image)
 
         if features:
-            points = [[left, top, width, height] for (left, top, width, height), neighbors in features]
+            points = [
+                [left, top, width, height]
+                for (left, top, width, height), neighbors in features
+            ]
         else:
             points = []
 
