@@ -4,14 +4,16 @@
 # thumbor imaging service
 # https://github.com/globocom/thumbor/wiki
 
-# Licensed under the MIT license: 
+# Licensed under the MIT license:
 # http://www.opensource.org/licenses/mit-license
 # Copyright (c) 2011 globo.com timehome@corp.globo.com
 
 import logging
 
+
 class Config:
     pass
 
-logger = logging.getLogger('remotecv')
-config = Config()
+
+logger = logging.getLogger("remotecv")  # pylint: disable=invalid-name
+config = Config()  # pylint: disable=invalid-name
